# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/cognito/cognito.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2
from eolymp.cognito import entitlement_pb2 as eolymp_dot_cognito_dot_entitlement__pb2
from eolymp.cognito import user_pb2 as eolymp_dot_cognito_dot_user__pb2
from eolymp.cognito import quota_pb2 as eolymp_dot_cognito_dot_quota__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/cognito/cognito.proto',
  package='eolymp.cognito',
  syntax='proto3',
  serialized_options=b'Z5github.com/eolymp/contracts/go/eolymp/cognito;cognito',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1c\x65olymp/cognito/cognito.proto\x12\x0e\x65olymp.cognito\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a!eolymp/wellknown/expression.proto\x1a eolymp/cognito/entitlement.proto\x1a\x19\x65olymp/cognito/user.proto\x1a\x1a\x65olymp/cognito/quota.proto\"\xbb\x02\n\x10\x43reateTokenInput\x12>\n\ngrant_type\x18\x01 \x01(\x0e\x32*.eolymp.cognito.CreateTokenInput.GrantType\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x10\n\x08password\x18\x03 \x01(\t\x12\x11\n\tclient_id\x18\x04 \x01(\t\x12\x15\n\rclient_secret\x18\x05 \x01(\t\x12\x0c\n\x04\x63ode\x18\x06 \x01(\t\x12\x15\n\rcode_verifier\x18\x07 \x01(\t\x12\r\n\x05scope\x18\x08 \x01(\t\x12\x15\n\rrefresh_token\x18\t \x01(\t\"N\n\tGrantType\x12\x08\n\x04NONE\x10\x00\x12\x0c\n\x08PASSWORD\x10\x01\x12\x16\n\x12\x41UTHORIZATION_CODE\x10\x02\x12\x11\n\rREFRESH_TOKEN\x10\x03\"\xaa\x01\n\x11\x43reateTokenOutput\x12\r\n\x05token\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12.\n\nexpires_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06scopes\x18\x04 \x03(\t\x12\x15\n\rrefresh_token\x18\n \x01(\t\x12\x0f\n\x07user_id\x18\x64 \x01(\t\x12\x10\n\x08username\x18\x65 \x01(\t\"%\n\x14IntrospectTokenInput\x12\r\n\x05token\x18\x01 \x01(\t\"\xa7\x01\n\x15IntrospectTokenOutput\x12\x0e\n\x06\x61\x63tive\x18\x01 \x01(\x08\x12\r\n\x05token\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12.\n\nexpires_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06scopes\x18\x05 \x03(\t\x12\x0f\n\x07user_id\x18\x64 \x01(\t\x12\x10\n\x08username\x18\x65 \x01(\t\"\xaf\x01\n\x18\x43reateAuthorizationInput\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12\x16\n\x0e\x63ode_challenge\x18\x02 \x01(\t\x12\x1d\n\x15\x63ode_challenge_method\x18\x03 \x01(\t\x12\x14\n\x0credirect_uri\x18\x04 \x01(\t\x12\x15\n\rresponse_type\x18\x05 \x01(\t\x12\r\n\x05scope\x18\x06 \x01(\t\x12\r\n\x05state\x18\x07 \x01(\t\"M\n\x19\x43reateAuthorizationOutput\x12\x1a\n\x12\x61uthorization_code\x18\x01 \x01(\t\x12\x14\n\x0credirect_uri\x18\x02 \x01(\t\"\x16\n\x14IntrospectQuotaInput\"\xe9\x01\n\x15IntrospectQuotaOutput\x12\x30\n\x11\x63ontests_per_user\x18\n \x01(\x0b\x32\x15.eolymp.cognito.Quota\x12\x33\n\x14problems_per_contest\x18\x0b \x01(\x0b\x32\x15.eolymp.cognito.Quota\x12\x37\n\x18participants_per_contest\x18\x0c \x01(\x0b\x32\x15.eolymp.cognito.Quota\x12\x30\n\x11problems_per_user\x18\x14 \x01(\x0b\x32\x15.eolymp.cognito.Quota\"\x15\n\x13IntrospectUserInput\":\n\x14IntrospectUserOutput\x12\"\n\x04user\x18\x01 \x01(\x0b\x32\x14.eolymp.cognito.User\"$\n\x11\x44\x65scribeUserInput\x12\x0f\n\x07user_id\x18\x01 \x01(\t\"8\n\x12\x44\x65scribeUserOutput\x12\"\n\x04user\x18\x01 \x01(\x0b\x32\x14.eolymp.cognito.User\"\xd2\x01\n\x0eListUsersInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x36\n\x07\x66ilters\x18( \x01(\x0b\x32%.eolymp.cognito.ListUsersInput.Filter\x1aj\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x34\n\x08username\x18\x02 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\"E\n\x0fListUsersOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12#\n\x05items\x18\x02 \x03(\x0b\x32\x14.eolymp.cognito.User\"x\n\x0f\x43reateUserInput\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x11\n\tfull_name\x18\x02 \x01(\t\x12\r\n\x05\x65mail\x18\x03 \x01(\t\x12\x10\n\x08password\x18\x04 \x01(\t\x12\x0f\n\x07\x63\x61ptcha\x18\n \x01(\t\x12\x0e\n\x06locale\x18\x14 \x01(\t\"D\n\x10\x43reateUserOutput\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x1f\n\x17\x65mail_confirmation_hint\x18\x02 \x01(\t\"\xac\x01\n\x0fNotifyUserInput\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x10\n\x08template\x18\x02 \x01(\t\x12\x43\n\nparameters\x18\x03 \x03(\x0b\x32/.eolymp.cognito.NotifyUserInput.ParametersEntry\x1a\x31\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"+\n\x10NotifyUserOutput\x12\x17\n\x0fnotification_id\x18\x01 \x01(\t\"3\n\x10VerifyEmailInput\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x0e\n\x06secret\x18\x02 \x01(\t\"\x13\n\x11VerifyEmailOutput\"!\n\x10UpdateEmailInput\x12\r\n\x05\x65mail\x18\x01 \x01(\t\"4\n\x11UpdateEmailOutput\x12\x1f\n\x17\x65mail_confirmation_hint\x18\x02 \x01(\t\"D\n\x12StartRecoveryInput\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x0f\n\x07\x63\x61ptcha\x18\x02 \x01(\t\x12\x0e\n\x06locale\x18\x14 \x01(\t\"2\n\x13StartRecoveryOutput\x12\x1b\n\x13\x65mail_recovery_hint\x18\x01 \x01(\t\"I\n\x14\x43ompleteRecoverInput\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x0e\n\x06secret\x18\x02 \x01(\t\x12\x10\n\x08password\x18\x03 \x01(\t\"\x17\n\x15\x43ompleteRecoverOutput\"\x16\n\x14IntrospectRolesInput\"&\n\x15IntrospectRolesOutput\x12\r\n\x05roles\x18\x01 \x03(\t\"!\n\x0eListRolesInput\x12\x0f\n\x07user_id\x18\x01 \x01(\t\" \n\x0fListRolesOutput\x12\r\n\x05roles\x18\x01 \x03(\t\"2\n\x10UpdateRolesInput\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\r\n\x05roles\x18\x02 \x03(\t\"\x13\n\x11UpdateRolesOutput\"\x17\n\x15ListEntitlementsInput\"K\n\x16ListEntitlementsOutput\x12\x31\n\x0c\x65ntitlements\x18\x01 \x03(\x0e\x32\x1b.eolymp.cognito.Entitlement\"!\n\x10RevokeTokenInput\x12\r\n\x05token\x18\x01 \x01(\t\"\x13\n\x11RevokeTokenOutput\"\"\n\x0cSignoutInput\x12\x12\n\neverywhere\x18\x01 \x01(\x08\"\x0f\n\rSignoutOutput2\x81\x13\n\x07\x43ognito\x12\x64\n\x0b\x43reateToken\x12 .eolymp.cognito.CreateTokenInput\x1a!.eolymp.cognito.CreateTokenOutput\"\x10\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xf0\x41\xf8\xe2\n\xac\x02\x12o\n\x0fIntrospectToken\x12$.eolymp.cognito.IntrospectTokenInput\x1a%.eolymp.cognito.IntrospectTokenOutput\"\x0f\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x12{\n\x13\x43reateAuthorization\x12(.eolymp.cognito.CreateAuthorizationInput\x1a).eolymp.cognito.CreateAuthorizationOutput\"\x0f\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\n\x12\x63\n\x0bRevokeToken\x12 .eolymp.cognito.RevokeTokenInput\x1a!.eolymp.cognito.RevokeTokenOutput\"\x0f\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x12W\n\x07Signout\x12\x1c.eolymp.cognito.SignoutInput\x1a\x1d.eolymp.cognito.SignoutOutput\"\x0f\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x12y\n\nCreateUser\x12\x1f.eolymp.cognito.CreateUserInput\x1a .eolymp.cognito.CreateUserOutput\"(\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x13\"\x0e/cognito/usersb\x01*\x12\x8d\x01\n\x0bVerifyEmail\x12 .eolymp.cognito.VerifyEmailInput\x1a!.eolymp.cognito.VerifyEmailOutput\"9\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x01\x82\xd3\xe4\x93\x02$\"\x1f/cognito/users/{user_id}/verifyb\x01*\x12\x81\x01\n\x0bUpdateEmail\x12 .eolymp.cognito.UpdateEmailInput\x1a!.eolymp.cognito.UpdateEmailOutput\"-\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x01\x82\xd3\xe4\x93\x02\x18\"\x13/cognito/self/emailb\x01*\x12\x85\x01\n\rStartRecovery\x12\".eolymp.cognito.StartRecoveryInput\x1a#.eolymp.cognito.StartRecoveryOutput\"+\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x16\"\x11/cognito/recoveryb\x01*\x12\x9b\x01\n\x10\x43ompleteRecovery\x12$.eolymp.cognito.CompleteRecoverInput\x1a%.eolymp.cognito.CompleteRecoverOutput\":\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02%\" /cognito/users/{user_id}/recoverb\x01*\x12\x87\x01\n\x0eIntrospectUser\x12#.eolymp.cognito.IntrospectUserInput\x1a$.eolymp.cognito.IntrospectUserOutput\"*\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x15\x12\r/cognito/selfb\x04user\x12\xa5\x01\n\x0c\x44\x65scribeUser\x12!.eolymp.cognito.DescribeUserInput\x1a\".eolymp.cognito.DescribeUserOutput\"N\x82\xe3\n\x15\x8a\xe3\n\x11\x63ognito:user:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00pA\xf8\xe2\nd\x82\xd3\xe4\x93\x02 \x12\x18/cognito/users/{user_id}b\x04user\x12\x8c\x01\n\tListUsers\x12\x1e.eolymp.cognito.ListUsersInput\x1a\x1f.eolymp.cognito.ListUsersOutput\">\x82\xe3\n\x15\x8a\xe3\n\x11\x63ognito:user:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00pA\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x10\x12\x0e/cognito/users\x12\x8a\x01\n\x0fIntrospectQuota\x12$.eolymp.cognito.IntrospectQuotaInput\x1a%.eolymp.cognito.IntrospectQuotaOutput\"*\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x15\x12\x13/cognito/self/quota\x12\x8a\x01\n\x0fIntrospectRoles\x12$.eolymp.cognito.IntrospectRolesInput\x1a%.eolymp.cognito.IntrospectRolesOutput\"*\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x15\x12\x13/cognito/self/roles\x12\x9c\x01\n\tListRoles\x12\x1e.eolymp.cognito.ListRolesInput\x1a\x1f.eolymp.cognito.ListRolesOutput\"N\x82\xe3\n\x15\x8a\xe3\n\x11\x63ognito:role:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x82\xd3\xe4\x93\x02 \x12\x1e/cognito/users/{user_id}/roles\x12\xa2\x01\n\x0bUpdateRoles\x12 .eolymp.cognito.UpdateRolesInput\x1a!.eolymp.cognito.UpdateRolesOutput\"N\x82\xe3\n\x15\x8a\xe3\n\x11\x63ognito:role:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x82\xd3\xe4\x93\x02 \x1a\x1e/cognito/users/{user_id}/roles\x12\x8f\x01\n\x10ListEntitlements\x12%.eolymp.cognito.ListEntitlementsInput\x1a&.eolymp.cognito.ListEntitlementsOutput\",\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x17\x12\x15/cognito/entitlementsB7Z5github.com/eolymp/contracts/go/eolymp/cognito;cognitob\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,eolymp_dot_annotations_dot_http__pb2.DESCRIPTOR,eolymp_dot_annotations_dot_ratelimit__pb2.DESCRIPTOR,eolymp_dot_annotations_dot_scope__pb2.DESCRIPTOR,eolymp_dot_wellknown_dot_expression__pb2.DESCRIPTOR,eolymp_dot_cognito_dot_entitlement__pb2.DESCRIPTOR,eolymp_dot_cognito_dot_user__pb2.DESCRIPTOR,eolymp_dot_cognito_dot_quota__pb2.DESCRIPTOR,])



_CREATETOKENINPUT_GRANTTYPE = _descriptor.EnumDescriptor(
  name='GrantType',
  full_name='eolymp.cognito.CreateTokenInput.GrantType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PASSWORD', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AUTHORIZATION_CODE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REFRESH_TOKEN', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=542,
  serialized_end=620,
)
_sym_db.RegisterEnumDescriptor(_CREATETOKENINPUT_GRANTTYPE)


_CREATETOKENINPUT = _descriptor.Descriptor(
  name='CreateTokenInput',
  full_name='eolymp.cognito.CreateTokenInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='grant_type', full_name='eolymp.cognito.CreateTokenInput.grant_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='username', full_name='eolymp.cognito.CreateTokenInput.username', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password', full_name='eolymp.cognito.CreateTokenInput.password', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_id', full_name='eolymp.cognito.CreateTokenInput.client_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_secret', full_name='eolymp.cognito.CreateTokenInput.client_secret', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='eolymp.cognito.CreateTokenInput.code', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code_verifier', full_name='eolymp.cognito.CreateTokenInput.code_verifier', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scope', full_name='eolymp.cognito.CreateTokenInput.scope', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='refresh_token', full_name='eolymp.cognito.CreateTokenInput.refresh_token', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CREATETOKENINPUT_GRANTTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=305,
  serialized_end=620,
)


_CREATETOKENOUTPUT = _descriptor.Descriptor(
  name='CreateTokenOutput',
  full_name='eolymp.cognito.CreateTokenOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='eolymp.cognito.CreateTokenOutput.token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='eolymp.cognito.CreateTokenOutput.type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expires_at', full_name='eolymp.cognito.CreateTokenOutput.expires_at', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scopes', full_name='eolymp.cognito.CreateTokenOutput.scopes', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='refresh_token', full_name='eolymp.cognito.CreateTokenOutput.refresh_token', index=4,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='eolymp.cognito.CreateTokenOutput.user_id', index=5,
      number=100, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='username', full_name='eolymp.cognito.CreateTokenOutput.username', index=6,
      number=101, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=623,
  serialized_end=793,
)


_INTROSPECTTOKENINPUT = _descriptor.Descriptor(
  name='IntrospectTokenInput',
  full_name='eolymp.cognito.IntrospectTokenInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='eolymp.cognito.IntrospectTokenInput.token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=795,
  serialized_end=832,
)


_INTROSPECTTOKENOUTPUT = _descriptor.Descriptor(
  name='IntrospectTokenOutput',
  full_name='eolymp.cognito.IntrospectTokenOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='active', full_name='eolymp.cognito.IntrospectTokenOutput.active', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='token', full_name='eolymp.cognito.IntrospectTokenOutput.token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='eolymp.cognito.IntrospectTokenOutput.type', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expires_at', full_name='eolymp.cognito.IntrospectTokenOutput.expires_at', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scopes', full_name='eolymp.cognito.IntrospectTokenOutput.scopes', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='eolymp.cognito.IntrospectTokenOutput.user_id', index=5,
      number=100, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='username', full_name='eolymp.cognito.IntrospectTokenOutput.username', index=6,
      number=101, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=835,
  serialized_end=1002,
)


_CREATEAUTHORIZATIONINPUT = _descriptor.Descriptor(
  name='CreateAuthorizationInput',
  full_name='eolymp.cognito.CreateAuthorizationInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_id', full_name='eolymp.cognito.CreateAuthorizationInput.client_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code_challenge', full_name='eolymp.cognito.CreateAuthorizationInput.code_challenge', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code_challenge_method', full_name='eolymp.cognito.CreateAuthorizationInput.code_challenge_method', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='redirect_uri', full_name='eolymp.cognito.CreateAuthorizationInput.redirect_uri', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_type', full_name='eolymp.cognito.CreateAuthorizationInput.response_type', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scope', full_name='eolymp.cognito.CreateAuthorizationInput.scope', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='eolymp.cognito.CreateAuthorizationInput.state', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1005,
  serialized_end=1180,
)


_CREATEAUTHORIZATIONOUTPUT = _descriptor.Descriptor(
  name='CreateAuthorizationOutput',
  full_name='eolymp.cognito.CreateAuthorizationOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='authorization_code', full_name='eolymp.cognito.CreateAuthorizationOutput.authorization_code', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='redirect_uri', full_name='eolymp.cognito.CreateAuthorizationOutput.redirect_uri', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1182,
  serialized_end=1259,
)


_INTROSPECTQUOTAINPUT = _descriptor.Descriptor(
  name='IntrospectQuotaInput',
  full_name='eolymp.cognito.IntrospectQuotaInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1261,
  serialized_end=1283,
)


_INTROSPECTQUOTAOUTPUT = _descriptor.Descriptor(
  name='IntrospectQuotaOutput',
  full_name='eolymp.cognito.IntrospectQuotaOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='contests_per_user', full_name='eolymp.cognito.IntrospectQuotaOutput.contests_per_user', index=0,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='problems_per_contest', full_name='eolymp.cognito.IntrospectQuotaOutput.problems_per_contest', index=1,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='participants_per_contest', full_name='eolymp.cognito.IntrospectQuotaOutput.participants_per_contest', index=2,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='problems_per_user', full_name='eolymp.cognito.IntrospectQuotaOutput.problems_per_user', index=3,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1286,
  serialized_end=1519,
)


_INTROSPECTUSERINPUT = _descriptor.Descriptor(
  name='IntrospectUserInput',
  full_name='eolymp.cognito.IntrospectUserInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1521,
  serialized_end=1542,
)


_INTROSPECTUSEROUTPUT = _descriptor.Descriptor(
  name='IntrospectUserOutput',
  full_name='eolymp.cognito.IntrospectUserOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user', full_name='eolymp.cognito.IntrospectUserOutput.user', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1544,
  serialized_end=1602,
)


_DESCRIBEUSERINPUT = _descriptor.Descriptor(
  name='DescribeUserInput',
  full_name='eolymp.cognito.DescribeUserInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='eolymp.cognito.DescribeUserInput.user_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1604,
  serialized_end=1640,
)


_DESCRIBEUSEROUTPUT = _descriptor.Descriptor(
  name='DescribeUserOutput',
  full_name='eolymp.cognito.DescribeUserOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user', full_name='eolymp.cognito.DescribeUserOutput.user', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1642,
  serialized_end=1698,
)


_LISTUSERSINPUT_FILTER = _descriptor.Descriptor(
  name='Filter',
  full_name='eolymp.cognito.ListUsersInput.Filter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='eolymp.cognito.ListUsersInput.Filter.id', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='username', full_name='eolymp.cognito.ListUsersInput.Filter.username', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1805,
  serialized_end=1911,
)

_LISTUSERSINPUT = _descriptor.Descriptor(
  name='ListUsersInput',
  full_name='eolymp.cognito.ListUsersInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='offset', full_name='eolymp.cognito.ListUsersInput.offset', index=0,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='eolymp.cognito.ListUsersInput.size', index=1,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filters', full_name='eolymp.cognito.ListUsersInput.filters', index=2,
      number=40, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTUSERSINPUT_FILTER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1701,
  serialized_end=1911,
)


_LISTUSERSOUTPUT = _descriptor.Descriptor(
  name='ListUsersOutput',
  full_name='eolymp.cognito.ListUsersOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='total', full_name='eolymp.cognito.ListUsersOutput.total', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='eolymp.cognito.ListUsersOutput.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1913,
  serialized_end=1982,
)


_CREATEUSERINPUT = _descriptor.Descriptor(
  name='CreateUserInput',
  full_name='eolymp.cognito.CreateUserInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='username', full_name='eolymp.cognito.CreateUserInput.username', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='full_name', full_name='eolymp.cognito.CreateUserInput.full_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='email', full_name='eolymp.cognito.CreateUserInput.email', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password', full_name='eolymp.cognito.CreateUserInput.password', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='captcha', full_name='eolymp.cognito.CreateUserInput.captcha', index=4,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='locale', full_name='eolymp.cognito.CreateUserInput.locale', index=5,
      number=20, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1984,
  serialized_end=2104,
)


_CREATEUSEROUTPUT = _descriptor.Descriptor(
  name='CreateUserOutput',
  full_name='eolymp.cognito.CreateUserOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='eolymp.cognito.CreateUserOutput.user_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='email_confirmation_hint', full_name='eolymp.cognito.CreateUserOutput.email_confirmation_hint', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2106,
  serialized_end=2174,
)


_NOTIFYUSERINPUT_PARAMETERSENTRY = _descriptor.Descriptor(
  name='ParametersEntry',
  full_name='eolymp.cognito.NotifyUserInput.ParametersEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='eolymp.cognito.NotifyUserInput.ParametersEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='eolymp.cognito.NotifyUserInput.ParametersEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2300,
  serialized_end=2349,
)

_NOTIFYUSERINPUT = _descriptor.Descriptor(
  name='NotifyUserInput',
  full_name='eolymp.cognito.NotifyUserInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='eolymp.cognito.NotifyUserInput.user_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='template', full_name='eolymp.cognito.NotifyUserInput.template', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parameters', full_name='eolymp.cognito.NotifyUserInput.parameters', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_NOTIFYUSERINPUT_PARAMETERSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2177,
  serialized_end=2349,
)


_NOTIFYUSEROUTPUT = _descriptor.Descriptor(
  name='NotifyUserOutput',
  full_name='eolymp.cognito.NotifyUserOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='notification_id', full_name='eolymp.cognito.NotifyUserOutput.notification_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2351,
  serialized_end=2394,
)


_VERIFYEMAILINPUT = _descriptor.Descriptor(
  name='VerifyEmailInput',
  full_name='eolymp.cognito.VerifyEmailInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='eolymp.cognito.VerifyEmailInput.user_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='eolymp.cognito.VerifyEmailInput.secret', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2396,
  serialized_end=2447,
)


_VERIFYEMAILOUTPUT = _descriptor.Descriptor(
  name='VerifyEmailOutput',
  full_name='eolymp.cognito.VerifyEmailOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2449,
  serialized_end=2468,
)


_UPDATEEMAILINPUT = _descriptor.Descriptor(
  name='UpdateEmailInput',
  full_name='eolymp.cognito.UpdateEmailInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='email', full_name='eolymp.cognito.UpdateEmailInput.email', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2470,
  serialized_end=2503,
)


_UPDATEEMAILOUTPUT = _descriptor.Descriptor(
  name='UpdateEmailOutput',
  full_name='eolymp.cognito.UpdateEmailOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='email_confirmation_hint', full_name='eolymp.cognito.UpdateEmailOutput.email_confirmation_hint', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2505,
  serialized_end=2557,
)


_STARTRECOVERYINPUT = _descriptor.Descriptor(
  name='StartRecoveryInput',
  full_name='eolymp.cognito.StartRecoveryInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='email', full_name='eolymp.cognito.StartRecoveryInput.email', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='captcha', full_name='eolymp.cognito.StartRecoveryInput.captcha', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='locale', full_name='eolymp.cognito.StartRecoveryInput.locale', index=2,
      number=20, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2559,
  serialized_end=2627,
)


_STARTRECOVERYOUTPUT = _descriptor.Descriptor(
  name='StartRecoveryOutput',
  full_name='eolymp.cognito.StartRecoveryOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='email_recovery_hint', full_name='eolymp.cognito.StartRecoveryOutput.email_recovery_hint', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2629,
  serialized_end=2679,
)


_COMPLETERECOVERINPUT = _descriptor.Descriptor(
  name='CompleteRecoverInput',
  full_name='eolymp.cognito.CompleteRecoverInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='eolymp.cognito.CompleteRecoverInput.user_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='eolymp.cognito.CompleteRecoverInput.secret', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password', full_name='eolymp.cognito.CompleteRecoverInput.password', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2681,
  serialized_end=2754,
)


_COMPLETERECOVEROUTPUT = _descriptor.Descriptor(
  name='CompleteRecoverOutput',
  full_name='eolymp.cognito.CompleteRecoverOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2756,
  serialized_end=2779,
)


_INTROSPECTROLESINPUT = _descriptor.Descriptor(
  name='IntrospectRolesInput',
  full_name='eolymp.cognito.IntrospectRolesInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2781,
  serialized_end=2803,
)


_INTROSPECTROLESOUTPUT = _descriptor.Descriptor(
  name='IntrospectRolesOutput',
  full_name='eolymp.cognito.IntrospectRolesOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='roles', full_name='eolymp.cognito.IntrospectRolesOutput.roles', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2805,
  serialized_end=2843,
)


_LISTROLESINPUT = _descriptor.Descriptor(
  name='ListRolesInput',
  full_name='eolymp.cognito.ListRolesInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='eolymp.cognito.ListRolesInput.user_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2845,
  serialized_end=2878,
)


_LISTROLESOUTPUT = _descriptor.Descriptor(
  name='ListRolesOutput',
  full_name='eolymp.cognito.ListRolesOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='roles', full_name='eolymp.cognito.ListRolesOutput.roles', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2880,
  serialized_end=2912,
)


_UPDATEROLESINPUT = _descriptor.Descriptor(
  name='UpdateRolesInput',
  full_name='eolymp.cognito.UpdateRolesInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='eolymp.cognito.UpdateRolesInput.user_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='roles', full_name='eolymp.cognito.UpdateRolesInput.roles', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2914,
  serialized_end=2964,
)


_UPDATEROLESOUTPUT = _descriptor.Descriptor(
  name='UpdateRolesOutput',
  full_name='eolymp.cognito.UpdateRolesOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2966,
  serialized_end=2985,
)


_LISTENTITLEMENTSINPUT = _descriptor.Descriptor(
  name='ListEntitlementsInput',
  full_name='eolymp.cognito.ListEntitlementsInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2987,
  serialized_end=3010,
)


_LISTENTITLEMENTSOUTPUT = _descriptor.Descriptor(
  name='ListEntitlementsOutput',
  full_name='eolymp.cognito.ListEntitlementsOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='entitlements', full_name='eolymp.cognito.ListEntitlementsOutput.entitlements', index=0,
      number=1, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3012,
  serialized_end=3087,
)


_REVOKETOKENINPUT = _descriptor.Descriptor(
  name='RevokeTokenInput',
  full_name='eolymp.cognito.RevokeTokenInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='eolymp.cognito.RevokeTokenInput.token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3089,
  serialized_end=3122,
)


_REVOKETOKENOUTPUT = _descriptor.Descriptor(
  name='RevokeTokenOutput',
  full_name='eolymp.cognito.RevokeTokenOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3124,
  serialized_end=3143,
)


_SIGNOUTINPUT = _descriptor.Descriptor(
  name='SignoutInput',
  full_name='eolymp.cognito.SignoutInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='everywhere', full_name='eolymp.cognito.SignoutInput.everywhere', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3145,
  serialized_end=3179,
)


_SIGNOUTOUTPUT = _descriptor.Descriptor(
  name='SignoutOutput',
  full_name='eolymp.cognito.SignoutOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3181,
  serialized_end=3196,
)

_CREATETOKENINPUT.fields_by_name['grant_type'].enum_type = _CREATETOKENINPUT_GRANTTYPE
_CREATETOKENINPUT_GRANTTYPE.containing_type = _CREATETOKENINPUT
_CREATETOKENOUTPUT.fields_by_name['expires_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_INTROSPECTTOKENOUTPUT.fields_by_name['expires_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_INTROSPECTQUOTAOUTPUT.fields_by_name['contests_per_user'].message_type = eolymp_dot_cognito_dot_quota__pb2._QUOTA
_INTROSPECTQUOTAOUTPUT.fields_by_name['problems_per_contest'].message_type = eolymp_dot_cognito_dot_quota__pb2._QUOTA
_INTROSPECTQUOTAOUTPUT.fields_by_name['participants_per_contest'].message_type = eolymp_dot_cognito_dot_quota__pb2._QUOTA
_INTROSPECTQUOTAOUTPUT.fields_by_name['problems_per_user'].message_type = eolymp_dot_cognito_dot_quota__pb2._QUOTA
_INTROSPECTUSEROUTPUT.fields_by_name['user'].message_type = eolymp_dot_cognito_dot_user__pb2._USER
_DESCRIBEUSEROUTPUT.fields_by_name['user'].message_type = eolymp_dot_cognito_dot_user__pb2._USER
_LISTUSERSINPUT_FILTER.fields_by_name['id'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONID
_LISTUSERSINPUT_FILTER.fields_by_name['username'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONSTRING
_LISTUSERSINPUT_FILTER.containing_type = _LISTUSERSINPUT
_LISTUSERSINPUT.fields_by_name['filters'].message_type = _LISTUSERSINPUT_FILTER
_LISTUSERSOUTPUT.fields_by_name['items'].message_type = eolymp_dot_cognito_dot_user__pb2._USER
_NOTIFYUSERINPUT_PARAMETERSENTRY.containing_type = _NOTIFYUSERINPUT
_NOTIFYUSERINPUT.fields_by_name['parameters'].message_type = _NOTIFYUSERINPUT_PARAMETERSENTRY
_LISTENTITLEMENTSOUTPUT.fields_by_name['entitlements'].enum_type = eolymp_dot_cognito_dot_entitlement__pb2._ENTITLEMENT
DESCRIPTOR.message_types_by_name['CreateTokenInput'] = _CREATETOKENINPUT
DESCRIPTOR.message_types_by_name['CreateTokenOutput'] = _CREATETOKENOUTPUT
DESCRIPTOR.message_types_by_name['IntrospectTokenInput'] = _INTROSPECTTOKENINPUT
DESCRIPTOR.message_types_by_name['IntrospectTokenOutput'] = _INTROSPECTTOKENOUTPUT
DESCRIPTOR.message_types_by_name['CreateAuthorizationInput'] = _CREATEAUTHORIZATIONINPUT
DESCRIPTOR.message_types_by_name['CreateAuthorizationOutput'] = _CREATEAUTHORIZATIONOUTPUT
DESCRIPTOR.message_types_by_name['IntrospectQuotaInput'] = _INTROSPECTQUOTAINPUT
DESCRIPTOR.message_types_by_name['IntrospectQuotaOutput'] = _INTROSPECTQUOTAOUTPUT
DESCRIPTOR.message_types_by_name['IntrospectUserInput'] = _INTROSPECTUSERINPUT
DESCRIPTOR.message_types_by_name['IntrospectUserOutput'] = _INTROSPECTUSEROUTPUT
DESCRIPTOR.message_types_by_name['DescribeUserInput'] = _DESCRIBEUSERINPUT
DESCRIPTOR.message_types_by_name['DescribeUserOutput'] = _DESCRIBEUSEROUTPUT
DESCRIPTOR.message_types_by_name['ListUsersInput'] = _LISTUSERSINPUT
DESCRIPTOR.message_types_by_name['ListUsersOutput'] = _LISTUSERSOUTPUT
DESCRIPTOR.message_types_by_name['CreateUserInput'] = _CREATEUSERINPUT
DESCRIPTOR.message_types_by_name['CreateUserOutput'] = _CREATEUSEROUTPUT
DESCRIPTOR.message_types_by_name['NotifyUserInput'] = _NOTIFYUSERINPUT
DESCRIPTOR.message_types_by_name['NotifyUserOutput'] = _NOTIFYUSEROUTPUT
DESCRIPTOR.message_types_by_name['VerifyEmailInput'] = _VERIFYEMAILINPUT
DESCRIPTOR.message_types_by_name['VerifyEmailOutput'] = _VERIFYEMAILOUTPUT
DESCRIPTOR.message_types_by_name['UpdateEmailInput'] = _UPDATEEMAILINPUT
DESCRIPTOR.message_types_by_name['UpdateEmailOutput'] = _UPDATEEMAILOUTPUT
DESCRIPTOR.message_types_by_name['StartRecoveryInput'] = _STARTRECOVERYINPUT
DESCRIPTOR.message_types_by_name['StartRecoveryOutput'] = _STARTRECOVERYOUTPUT
DESCRIPTOR.message_types_by_name['CompleteRecoverInput'] = _COMPLETERECOVERINPUT
DESCRIPTOR.message_types_by_name['CompleteRecoverOutput'] = _COMPLETERECOVEROUTPUT
DESCRIPTOR.message_types_by_name['IntrospectRolesInput'] = _INTROSPECTROLESINPUT
DESCRIPTOR.message_types_by_name['IntrospectRolesOutput'] = _INTROSPECTROLESOUTPUT
DESCRIPTOR.message_types_by_name['ListRolesInput'] = _LISTROLESINPUT
DESCRIPTOR.message_types_by_name['ListRolesOutput'] = _LISTROLESOUTPUT
DESCRIPTOR.message_types_by_name['UpdateRolesInput'] = _UPDATEROLESINPUT
DESCRIPTOR.message_types_by_name['UpdateRolesOutput'] = _UPDATEROLESOUTPUT
DESCRIPTOR.message_types_by_name['ListEntitlementsInput'] = _LISTENTITLEMENTSINPUT
DESCRIPTOR.message_types_by_name['ListEntitlementsOutput'] = _LISTENTITLEMENTSOUTPUT
DESCRIPTOR.message_types_by_name['RevokeTokenInput'] = _REVOKETOKENINPUT
DESCRIPTOR.message_types_by_name['RevokeTokenOutput'] = _REVOKETOKENOUTPUT
DESCRIPTOR.message_types_by_name['SignoutInput'] = _SIGNOUTINPUT
DESCRIPTOR.message_types_by_name['SignoutOutput'] = _SIGNOUTOUTPUT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateTokenInput = _reflection.GeneratedProtocolMessageType('CreateTokenInput', (_message.Message,), {
  'DESCRIPTOR' : _CREATETOKENINPUT,
  '__module__' : 'eolymp.cognito.cognito_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.cognito.CreateTokenInput)
  })
_sym_db.RegisterMessage(CreateTokenInput)

CreateTokenOutput = _reflection.GeneratedProtocolMessageType('CreateTokenOutput', (_message.Message,), {
  'DESCRIPTOR' : _CREATETOKENOUTPUT,
  '__module__' : 'eolymp.cognito.cognito_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.cognito.CreateTokenOutput)
  })
_sym_db.RegisterMessage(CreateTokenOutput)

IntrospectTokenInput = _reflection.GeneratedProtocolMessageType('IntrospectTokenInput', (_message.Message,), {
  'DESCRIPTOR' : _INTROSPECTTOKENINPUT,
  '__module__' : 'eolymp.cognito.cognito_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.cognito.IntrospectTokenInput)
  })
_sym_db.RegisterMessage(IntrospectTokenInput)

IntrospectTokenOutput = _reflection.GeneratedProtocolMessageType('IntrospectTokenOutput', (_message.Message,), {
  'DESCRIPTOR' : _INTROSPECTTOKENOUTPUT,
  '__module__' : 'eolymp.cognito.cognito_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.cognito.IntrospectTokenOutput)
  })
_sym_db.RegisterMessage(IntrospectTokenOutput)

CreateAuthorizationInput = _reflection.GeneratedProtocolMessageType('CreateAuthorizationInput', (_message.Message,), {
  'DESCRIPTOR' : _CREATEAUTHORIZATIONINPUT,
  '__module__' : 'eolymp.cognito.cognito_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.cognito.CreateAuthorizationInput)
  })
_sym_db.RegisterMessage(CreateAuthorizationInput)

CreateAuthorizationOutput = _reflection.GeneratedProtocolMessageType('CreateAuthorizationOutput', (_message.Message,), {
  'DESCRIPTOR' : _CREATEAUTHORIZATIONOUTPUT,
  '__module__' : 'eolymp.cognito.cognito_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.cognito.CreateAuthorizationOutput)
  })
_sym_db.RegisterMessage(CreateAuthorizationOutput)

IntrospectQuotaInput = _reflection.GeneratedProtocolMessageType('IntrospectQuotaInput', (_message.Message,), {
  'DESCRIPTOR' : _INTROSPECTQUOTAINPUT,
  '__module__' : 'eolymp.cognito.cognito_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.cognito.IntrospectQuotaInput)
  })
_sym_db.RegisterMessage(IntrospectQuotaInput)

IntrospectQuotaOutput = _reflection.GeneratedProtocolMessageType('IntrospectQuotaOutput', (_message.Message,), {
  'DESCRIPTOR' : _INTROSPECTQUOTAOUTPUT,
  '__module__' : 'eolymp.cognito.cognito_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.cognito.IntrospectQuotaOutput)
  })
_sym_db.RegisterMessage(IntrospectQuotaOutput)

IntrospectUserInput = _reflection.GeneratedProtocolMessageType('IntrospectUserInput', (_message.Message,), {
  'DESCRIPTOR' : _INTROSPECTUSERINPUT,
  '__module__' : 'eolymp.cognito.cognito_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.cognito.IntrospectUserInput)
  })
_sym_db.RegisterMessage(IntrospectUserInput)

IntrospectUserOutput = _reflection.GeneratedProtocolMessageType('IntrospectUserOutput', (_message.Message,), {
  'DESCRIPTOR' : _INTROSPECTUSEROUTPUT,
  '__module__' : 'eolymp.cognito.cognito_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.cognito.IntrospectUserOutput)
  })
_sym_db.RegisterMessage(IntrospectUserOutput)

DescribeUserInput = _reflection.GeneratedProtocolMessageType('DescribeUserInput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEUSERINPUT,
  '__module__' : 'eolymp.cognito.cognito_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.cognito.DescribeUserInput)
  })
_sym_db.RegisterMessage(DescribeUserInput)

DescribeUserOutput = _reflection.GeneratedProtocolMessageType('DescribeUserOutput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEUSEROUTPUT,
  '__module__' : 'eolymp.cognito.cognito_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.cognito.DescribeUserOutput)
  })
_sym_db.RegisterMessage(DescribeUserOutput)

ListUsersInput = _reflection.GeneratedProtocolMessageType('ListUsersInput', (_message.Message,), {

  'Filter' : _reflection.GeneratedProtocolMessageType('Filter', (_message.Message,), {
    'DESCRIPTOR' : _LISTUSERSINPUT_FILTER,
    '__module__' : 'eolymp.cognito.cognito_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.cognito.ListUsersInput.Filter)
    })
  ,
  'DESCRIPTOR' : _LISTUSERSINPUT,
  '__module__' : 'eolymp.cognito.cognito_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.cognito.ListUsersInput)
  })
_sym_db.RegisterMessage(ListUsersInput)
_sym_db.RegisterMessage(ListUsersInput.Filter)

ListUsersOutput = _reflection.GeneratedProtocolMessageType('ListUsersOutput', (_message.Message,), {
  'DESCRIPTOR' : _LISTUSERSOUTPUT,
  '__module__' : 'eolymp.cognito.cognito_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.cognito.ListUsersOutput)
  })
_sym_db.RegisterMessage(ListUsersOutput)

CreateUserInput = _reflection.GeneratedProtocolMessageType('CreateUserInput', (_message.Message,), {
  'DESCRIPTOR' : _CREATEUSERINPUT,
  '__module__' : 'eolymp.cognito.cognito_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.cognito.CreateUserInput)
  })
_sym_db.RegisterMessage(CreateUserInput)

CreateUserOutput = _reflection.GeneratedProtocolMessageType('CreateUserOutput', (_message.Message,), {
  'DESCRIPTOR' : _CREATEUSEROUTPUT,
  '__module__' : 'eolymp.cognito.cognito_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.cognito.CreateUserOutput)
  })
_sym_db.RegisterMessage(CreateUserOutput)

NotifyUserInput = _reflection.GeneratedProtocolMessageType('NotifyUserInput', (_message.Message,), {

  'ParametersEntry' : _reflection.GeneratedProtocolMessageType('ParametersEntry', (_message.Message,), {
    'DESCRIPTOR' : _NOTIFYUSERINPUT_PARAMETERSENTRY,
    '__module__' : 'eolymp.cognito.cognito_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.cognito.NotifyUserInput.ParametersEntry)
    })
  ,
  'DESCRIPTOR' : _NOTIFYUSERINPUT,
  '__module__' : 'eolymp.cognito.cognito_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.cognito.NotifyUserInput)
  })
_sym_db.RegisterMessage(NotifyUserInput)
_sym_db.RegisterMessage(NotifyUserInput.ParametersEntry)

NotifyUserOutput = _reflection.GeneratedProtocolMessageType('NotifyUserOutput', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFYUSEROUTPUT,
  '__module__' : 'eolymp.cognito.cognito_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.cognito.NotifyUserOutput)
  })
_sym_db.RegisterMessage(NotifyUserOutput)

VerifyEmailInput = _reflection.GeneratedProtocolMessageType('VerifyEmailInput', (_message.Message,), {
  'DESCRIPTOR' : _VERIFYEMAILINPUT,
  '__module__' : 'eolymp.cognito.cognito_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.cognito.VerifyEmailInput)
  })
_sym_db.RegisterMessage(VerifyEmailInput)

VerifyEmailOutput = _reflection.GeneratedProtocolMessageType('VerifyEmailOutput', (_message.Message,), {
  'DESCRIPTOR' : _VERIFYEMAILOUTPUT,
  '__module__' : 'eolymp.cognito.cognito_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.cognito.VerifyEmailOutput)
  })
_sym_db.RegisterMessage(VerifyEmailOutput)

UpdateEmailInput = _reflection.GeneratedProtocolMessageType('UpdateEmailInput', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEEMAILINPUT,
  '__module__' : 'eolymp.cognito.cognito_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.cognito.UpdateEmailInput)
  })
_sym_db.RegisterMessage(UpdateEmailInput)

UpdateEmailOutput = _reflection.GeneratedProtocolMessageType('UpdateEmailOutput', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEEMAILOUTPUT,
  '__module__' : 'eolymp.cognito.cognito_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.cognito.UpdateEmailOutput)
  })
_sym_db.RegisterMessage(UpdateEmailOutput)

StartRecoveryInput = _reflection.GeneratedProtocolMessageType('StartRecoveryInput', (_message.Message,), {
  'DESCRIPTOR' : _STARTRECOVERYINPUT,
  '__module__' : 'eolymp.cognito.cognito_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.cognito.StartRecoveryInput)
  })
_sym_db.RegisterMessage(StartRecoveryInput)

StartRecoveryOutput = _reflection.GeneratedProtocolMessageType('StartRecoveryOutput', (_message.Message,), {
  'DESCRIPTOR' : _STARTRECOVERYOUTPUT,
  '__module__' : 'eolymp.cognito.cognito_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.cognito.StartRecoveryOutput)
  })
_sym_db.RegisterMessage(StartRecoveryOutput)

CompleteRecoverInput = _reflection.GeneratedProtocolMessageType('CompleteRecoverInput', (_message.Message,), {
  'DESCRIPTOR' : _COMPLETERECOVERINPUT,
  '__module__' : 'eolymp.cognito.cognito_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.cognito.CompleteRecoverInput)
  })
_sym_db.RegisterMessage(CompleteRecoverInput)

CompleteRecoverOutput = _reflection.GeneratedProtocolMessageType('CompleteRecoverOutput', (_message.Message,), {
  'DESCRIPTOR' : _COMPLETERECOVEROUTPUT,
  '__module__' : 'eolymp.cognito.cognito_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.cognito.CompleteRecoverOutput)
  })
_sym_db.RegisterMessage(CompleteRecoverOutput)

IntrospectRolesInput = _reflection.GeneratedProtocolMessageType('IntrospectRolesInput', (_message.Message,), {
  'DESCRIPTOR' : _INTROSPECTROLESINPUT,
  '__module__' : 'eolymp.cognito.cognito_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.cognito.IntrospectRolesInput)
  })
_sym_db.RegisterMessage(IntrospectRolesInput)

IntrospectRolesOutput = _reflection.GeneratedProtocolMessageType('IntrospectRolesOutput', (_message.Message,), {
  'DESCRIPTOR' : _INTROSPECTROLESOUTPUT,
  '__module__' : 'eolymp.cognito.cognito_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.cognito.IntrospectRolesOutput)
  })
_sym_db.RegisterMessage(IntrospectRolesOutput)

ListRolesInput = _reflection.GeneratedProtocolMessageType('ListRolesInput', (_message.Message,), {
  'DESCRIPTOR' : _LISTROLESINPUT,
  '__module__' : 'eolymp.cognito.cognito_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.cognito.ListRolesInput)
  })
_sym_db.RegisterMessage(ListRolesInput)

ListRolesOutput = _reflection.GeneratedProtocolMessageType('ListRolesOutput', (_message.Message,), {
  'DESCRIPTOR' : _LISTROLESOUTPUT,
  '__module__' : 'eolymp.cognito.cognito_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.cognito.ListRolesOutput)
  })
_sym_db.RegisterMessage(ListRolesOutput)

UpdateRolesInput = _reflection.GeneratedProtocolMessageType('UpdateRolesInput', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEROLESINPUT,
  '__module__' : 'eolymp.cognito.cognito_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.cognito.UpdateRolesInput)
  })
_sym_db.RegisterMessage(UpdateRolesInput)

UpdateRolesOutput = _reflection.GeneratedProtocolMessageType('UpdateRolesOutput', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEROLESOUTPUT,
  '__module__' : 'eolymp.cognito.cognito_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.cognito.UpdateRolesOutput)
  })
_sym_db.RegisterMessage(UpdateRolesOutput)

ListEntitlementsInput = _reflection.GeneratedProtocolMessageType('ListEntitlementsInput', (_message.Message,), {
  'DESCRIPTOR' : _LISTENTITLEMENTSINPUT,
  '__module__' : 'eolymp.cognito.cognito_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.cognito.ListEntitlementsInput)
  })
_sym_db.RegisterMessage(ListEntitlementsInput)

ListEntitlementsOutput = _reflection.GeneratedProtocolMessageType('ListEntitlementsOutput', (_message.Message,), {
  'DESCRIPTOR' : _LISTENTITLEMENTSOUTPUT,
  '__module__' : 'eolymp.cognito.cognito_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.cognito.ListEntitlementsOutput)
  })
_sym_db.RegisterMessage(ListEntitlementsOutput)

RevokeTokenInput = _reflection.GeneratedProtocolMessageType('RevokeTokenInput', (_message.Message,), {
  'DESCRIPTOR' : _REVOKETOKENINPUT,
  '__module__' : 'eolymp.cognito.cognito_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.cognito.RevokeTokenInput)
  })
_sym_db.RegisterMessage(RevokeTokenInput)

RevokeTokenOutput = _reflection.GeneratedProtocolMessageType('RevokeTokenOutput', (_message.Message,), {
  'DESCRIPTOR' : _REVOKETOKENOUTPUT,
  '__module__' : 'eolymp.cognito.cognito_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.cognito.RevokeTokenOutput)
  })
_sym_db.RegisterMessage(RevokeTokenOutput)

SignoutInput = _reflection.GeneratedProtocolMessageType('SignoutInput', (_message.Message,), {
  'DESCRIPTOR' : _SIGNOUTINPUT,
  '__module__' : 'eolymp.cognito.cognito_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.cognito.SignoutInput)
  })
_sym_db.RegisterMessage(SignoutInput)

SignoutOutput = _reflection.GeneratedProtocolMessageType('SignoutOutput', (_message.Message,), {
  'DESCRIPTOR' : _SIGNOUTOUTPUT,
  '__module__' : 'eolymp.cognito.cognito_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.cognito.SignoutOutput)
  })
_sym_db.RegisterMessage(SignoutOutput)


DESCRIPTOR._options = None
_NOTIFYUSERINPUT_PARAMETERSENTRY._options = None

_COGNITO = _descriptor.ServiceDescriptor(
  name='Cognito',
  full_name='eolymp.cognito.Cognito',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=3199,
  serialized_end=5632,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateToken',
    full_name='eolymp.cognito.Cognito.CreateToken',
    index=0,
    containing_service=None,
    input_type=_CREATETOKENINPUT,
    output_type=_CREATETOKENOUTPUT,
    serialized_options=b'\352\342\n\014\365\342\n\000\000\360A\370\342\n\254\002',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='IntrospectToken',
    full_name='eolymp.cognito.Cognito.IntrospectToken',
    index=1,
    containing_service=None,
    input_type=_INTROSPECTTOKENINPUT,
    output_type=_INTROSPECTTOKENOUTPUT,
    serialized_options=b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\n',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateAuthorization',
    full_name='eolymp.cognito.Cognito.CreateAuthorization',
    index=2,
    containing_service=None,
    input_type=_CREATEAUTHORIZATIONINPUT,
    output_type=_CREATEAUTHORIZATIONOUTPUT,
    serialized_options=b'\352\342\n\013\365\342\n\n\327#>\370\342\n\n',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RevokeToken',
    full_name='eolymp.cognito.Cognito.RevokeToken',
    index=3,
    containing_service=None,
    input_type=_REVOKETOKENINPUT,
    output_type=_REVOKETOKENOUTPUT,
    serialized_options=b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\n',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Signout',
    full_name='eolymp.cognito.Cognito.Signout',
    index=4,
    containing_service=None,
    input_type=_SIGNOUTINPUT,
    output_type=_SIGNOUTOUTPUT,
    serialized_options=b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\n',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateUser',
    full_name='eolymp.cognito.Cognito.CreateUser',
    index=5,
    containing_service=None,
    input_type=_CREATEUSERINPUT,
    output_type=_CREATEUSEROUTPUT,
    serialized_options=b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002\023\"\016/cognito/usersb\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='VerifyEmail',
    full_name='eolymp.cognito.Cognito.VerifyEmail',
    index=6,
    containing_service=None,
    input_type=_VERIFYEMAILINPUT,
    output_type=_VERIFYEMAILOUTPUT,
    serialized_options=b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\001\202\323\344\223\002$\"\037/cognito/users/{user_id}/verifyb\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateEmail',
    full_name='eolymp.cognito.Cognito.UpdateEmail',
    index=7,
    containing_service=None,
    input_type=_UPDATEEMAILINPUT,
    output_type=_UPDATEEMAILOUTPUT,
    serialized_options=b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\001\202\323\344\223\002\030\"\023/cognito/self/emailb\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StartRecovery',
    full_name='eolymp.cognito.Cognito.StartRecovery',
    index=8,
    containing_service=None,
    input_type=_STARTRECOVERYINPUT,
    output_type=_STARTRECOVERYOUTPUT,
    serialized_options=b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002\026\"\021/cognito/recoveryb\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CompleteRecovery',
    full_name='eolymp.cognito.Cognito.CompleteRecovery',
    index=9,
    containing_service=None,
    input_type=_COMPLETERECOVERINPUT,
    output_type=_COMPLETERECOVEROUTPUT,
    serialized_options=b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002%\" /cognito/users/{user_id}/recoverb\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='IntrospectUser',
    full_name='eolymp.cognito.Cognito.IntrospectUser',
    index=10,
    containing_service=None,
    input_type=_INTROSPECTUSERINPUT,
    output_type=_INTROSPECTUSEROUTPUT,
    serialized_options=b'\352\342\n\013\365\342\n\n\327#>\370\342\n\n\202\323\344\223\002\025\022\r/cognito/selfb\004user',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DescribeUser',
    full_name='eolymp.cognito.Cognito.DescribeUser',
    index=11,
    containing_service=None,
    input_type=_DESCRIBEUSERINPUT,
    output_type=_DESCRIBEUSEROUTPUT,
    serialized_options=b'\202\343\n\025\212\343\n\021cognito:user:read\352\342\n\013\365\342\n\000\000pA\370\342\nd\202\323\344\223\002 \022\030/cognito/users/{user_id}b\004user',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListUsers',
    full_name='eolymp.cognito.Cognito.ListUsers',
    index=12,
    containing_service=None,
    input_type=_LISTUSERSINPUT,
    output_type=_LISTUSERSOUTPUT,
    serialized_options=b'\202\343\n\025\212\343\n\021cognito:user:read\352\342\n\013\365\342\n\000\000pA\370\342\nd\202\323\344\223\002\020\022\016/cognito/users',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='IntrospectQuota',
    full_name='eolymp.cognito.Cognito.IntrospectQuota',
    index=13,
    containing_service=None,
    input_type=_INTROSPECTQUOTAINPUT,
    output_type=_INTROSPECTQUOTAOUTPUT,
    serialized_options=b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\n\202\323\344\223\002\025\022\023/cognito/self/quota',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='IntrospectRoles',
    full_name='eolymp.cognito.Cognito.IntrospectRoles',
    index=14,
    containing_service=None,
    input_type=_INTROSPECTROLESINPUT,
    output_type=_INTROSPECTROLESOUTPUT,
    serialized_options=b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\n\202\323\344\223\002\025\022\023/cognito/self/roles',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListRoles',
    full_name='eolymp.cognito.Cognito.ListRoles',
    index=15,
    containing_service=None,
    input_type=_LISTROLESINPUT,
    output_type=_LISTROLESOUTPUT,
    serialized_options=b'\202\343\n\025\212\343\n\021cognito:role:read\352\342\n\013\365\342\n\000\000\200?\370\342\n\n\202\323\344\223\002 \022\036/cognito/users/{user_id}/roles',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateRoles',
    full_name='eolymp.cognito.Cognito.UpdateRoles',
    index=16,
    containing_service=None,
    input_type=_UPDATEROLESINPUT,
    output_type=_UPDATEROLESOUTPUT,
    serialized_options=b'\202\343\n\025\212\343\n\021cognito:role:read\352\342\n\013\365\342\n\000\000\200?\370\342\n\n\202\323\344\223\002 \032\036/cognito/users/{user_id}/roles',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListEntitlements',
    full_name='eolymp.cognito.Cognito.ListEntitlements',
    index=17,
    containing_service=None,
    input_type=_LISTENTITLEMENTSINPUT,
    output_type=_LISTENTITLEMENTSOUTPUT,
    serialized_options=b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\n\202\323\344\223\002\027\022\025/cognito/entitlements',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_COGNITO)

DESCRIPTOR.services_by_name['Cognito'] = _COGNITO

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/wellknown/errors.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/wellknown/errors.proto',
  package='eolymp.wellknown',
  syntax='proto3',
  serialized_options=b'Z9github.com/eolymp/contracts/go/eolymp/wellknown;wellknown',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1d\x65olymp/wellknown/errors.proto\x12\x10\x65olymp.wellknown\" \n\x0b\x45rrorReport\x12\x11\n\treport_id\x18\x01 \x01(\t\"Z\n\x0fInvalidArgument\x12\x15\n\rargument_path\x18\x01 \x01(\t\x12\x30\n\nvalidation\x18\x02 \x03(\x0b\x32\x1c.eolymp.wellknown.Validation\"u\n\nValidation\x12\x15\n\rargument_path\x18\x01 \x03(\t\x12\x15\n\rerror_message\x18\x02 \x01(\t\x12\x39\n\x0clocalization\x18\x03 \x01(\x0b\x32#.eolymp.wellknown.ErrorLocalization\"-\n\rQuotaExceeded\x12\r\n\x05quota\x18\x01 \x01(\x05\x12\r\n\x05usage\x18\x02 \x01(\x05\"\xaa\x01\n\x11\x45rrorLocalization\x12\x12\n\nphrase_key\x18\x01 \x01(\t\x12L\n\rphrase_params\x18\x02 \x03(\x0b\x32\x35.eolymp.wellknown.ErrorLocalization.PhraseParamsEntry\x1a\x33\n\x11PhraseParamsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42;Z9github.com/eolymp/contracts/go/eolymp/wellknown;wellknownb\x06proto3'
)




_ERRORREPORT = _descriptor.Descriptor(
  name='ErrorReport',
  full_name='eolymp.wellknown.ErrorReport',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='report_id', full_name='eolymp.wellknown.ErrorReport.report_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=51,
  serialized_end=83,
)


_INVALIDARGUMENT = _descriptor.Descriptor(
  name='InvalidArgument',
  full_name='eolymp.wellknown.InvalidArgument',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='argument_path', full_name='eolymp.wellknown.InvalidArgument.argument_path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='validation', full_name='eolymp.wellknown.InvalidArgument.validation', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=85,
  serialized_end=175,
)


_VALIDATION = _descriptor.Descriptor(
  name='Validation',
  full_name='eolymp.wellknown.Validation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='argument_path', full_name='eolymp.wellknown.Validation.argument_path', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error_message', full_name='eolymp.wellknown.Validation.error_message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='localization', full_name='eolymp.wellknown.Validation.localization', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=177,
  serialized_end=294,
)


_QUOTAEXCEEDED = _descriptor.Descriptor(
  name='QuotaExceeded',
  full_name='eolymp.wellknown.QuotaExceeded',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='quota', full_name='eolymp.wellknown.QuotaExceeded.quota', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='usage', full_name='eolymp.wellknown.QuotaExceeded.usage', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=296,
  serialized_end=341,
)


_ERRORLOCALIZATION_PHRASEPARAMSENTRY = _descriptor.Descriptor(
  name='PhraseParamsEntry',
  full_name='eolymp.wellknown.ErrorLocalization.PhraseParamsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='eolymp.wellknown.ErrorLocalization.PhraseParamsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='eolymp.wellknown.ErrorLocalization.PhraseParamsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=463,
  serialized_end=514,
)

_ERRORLOCALIZATION = _descriptor.Descriptor(
  name='ErrorLocalization',
  full_name='eolymp.wellknown.ErrorLocalization',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='phrase_key', full_name='eolymp.wellknown.ErrorLocalization.phrase_key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='phrase_params', full_name='eolymp.wellknown.ErrorLocalization.phrase_params', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ERRORLOCALIZATION_PHRASEPARAMSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=344,
  serialized_end=514,
)

_INVALIDARGUMENT.fields_by_name['validation'].message_type = _VALIDATION
_VALIDATION.fields_by_name['localization'].message_type = _ERRORLOCALIZATION
_ERRORLOCALIZATION_PHRASEPARAMSENTRY.containing_type = _ERRORLOCALIZATION
_ERRORLOCALIZATION.fields_by_name['phrase_params'].message_type = _ERRORLOCALIZATION_PHRASEPARAMSENTRY
DESCRIPTOR.message_types_by_name['ErrorReport'] = _ERRORREPORT
DESCRIPTOR.message_types_by_name['InvalidArgument'] = _INVALIDARGUMENT
DESCRIPTOR.message_types_by_name['Validation'] = _VALIDATION
DESCRIPTOR.message_types_by_name['QuotaExceeded'] = _QUOTAEXCEEDED
DESCRIPTOR.message_types_by_name['ErrorLocalization'] = _ERRORLOCALIZATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ErrorReport = _reflection.GeneratedProtocolMessageType('ErrorReport', (_message.Message,), {
  'DESCRIPTOR' : _ERRORREPORT,
  '__module__' : 'eolymp.wellknown.errors_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.wellknown.ErrorReport)
  })
_sym_db.RegisterMessage(ErrorReport)

InvalidArgument = _reflection.GeneratedProtocolMessageType('InvalidArgument', (_message.Message,), {
  'DESCRIPTOR' : _INVALIDARGUMENT,
  '__module__' : 'eolymp.wellknown.errors_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.wellknown.InvalidArgument)
  })
_sym_db.RegisterMessage(InvalidArgument)

Validation = _reflection.GeneratedProtocolMessageType('Validation', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATION,
  '__module__' : 'eolymp.wellknown.errors_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.wellknown.Validation)
  })
_sym_db.RegisterMessage(Validation)

QuotaExceeded = _reflection.GeneratedProtocolMessageType('QuotaExceeded', (_message.Message,), {
  'DESCRIPTOR' : _QUOTAEXCEEDED,
  '__module__' : 'eolymp.wellknown.errors_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.wellknown.QuotaExceeded)
  })
_sym_db.RegisterMessage(QuotaExceeded)

ErrorLocalization = _reflection.GeneratedProtocolMessageType('ErrorLocalization', (_message.Message,), {

  'PhraseParamsEntry' : _reflection.GeneratedProtocolMessageType('PhraseParamsEntry', (_message.Message,), {
    'DESCRIPTOR' : _ERRORLOCALIZATION_PHRASEPARAMSENTRY,
    '__module__' : 'eolymp.wellknown.errors_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.wellknown.ErrorLocalization.PhraseParamsEntry)
    })
  ,
  'DESCRIPTOR' : _ERRORLOCALIZATION,
  '__module__' : 'eolymp.wellknown.errors_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.wellknown.ErrorLocalization)
  })
_sym_db.RegisterMessage(ErrorLocalization)
_sym_db.RegisterMessage(ErrorLocalization.PhraseParamsEntry)


DESCRIPTOR._options = None
_ERRORLOCALIZATION_PHRASEPARAMSENTRY._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/universe/member.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/universe/member.proto',
  package='eolymp.universe',
  syntax='proto3',
  serialized_options=b'Z7github.com/eolymp/contracts/go/eolymp/universe;universe',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1c\x65olymp/universe/member.proto\x12\x0f\x65olymp.universe\"E\n\x06Member\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x0c\n\x04role\x18\n \x01(\t\x12\x10\n\x08username\x18\x14 \x01(\tB9Z7github.com/eolymp/contracts/go/eolymp/universe;universeb\x06proto3'
)




_MEMBER = _descriptor.Descriptor(
  name='Member',
  full_name='eolymp.universe.Member',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='eolymp.universe.Member.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='eolymp.universe.Member.user_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='role', full_name='eolymp.universe.Member.role', index=2,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='username', full_name='eolymp.universe.Member.username', index=3,
      number=20, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=49,
  serialized_end=118,
)

DESCRIPTOR.message_types_by_name['Member'] = _MEMBER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Member = _reflection.GeneratedProtocolMessageType('Member', (_message.Message,), {
  'DESCRIPTOR' : _MEMBER,
  '__module__' : 'eolymp.universe.member_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.universe.Member)
  })
_sym_db.RegisterMessage(Member)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/annotations/scope.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/annotations/scope.proto',
  package='eolymp.api',
  syntax='proto3',
  serialized_options=b'Z=github.com/eolymp/contracts/go/eolymp/annotations;annotations',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1e\x65olymp/annotations/scope.proto\x12\neolymp.api\x1a google/protobuf/descriptor.proto\"\x18\n\x05Scope\x12\x0f\n\x05scope\x18\xb1\xac\x01 \x03(\t:B\n\x05scope\x12\x1e.google.protobuf.MethodOptions\x18\xb0\xac\x01 \x01(\x0b\x32\x11.eolymp.api.ScopeB?Z=github.com/eolymp/contracts/go/eolymp/annotations;annotationsb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_descriptor__pb2.DESCRIPTOR,])


SCOPE_FIELD_NUMBER = 22064
scope = _descriptor.FieldDescriptor(
  name='scope', full_name='eolymp.api.scope', index=0,
  number=22064, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)


_SCOPE = _descriptor.Descriptor(
  name='Scope',
  full_name='eolymp.api.Scope',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scope', full_name='eolymp.api.Scope.scope', index=0,
      number=22065, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=80,
  serialized_end=104,
)

DESCRIPTOR.message_types_by_name['Scope'] = _SCOPE
DESCRIPTOR.extensions_by_name['scope'] = scope
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Scope = _reflection.GeneratedProtocolMessageType('Scope', (_message.Message,), {
  'DESCRIPTOR' : _SCOPE,
  '__module__' : 'eolymp.annotations.scope_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.api.Scope)
  })
_sym_db.RegisterMessage(Scope)

scope.message_type = _SCOPE
google_dot_protobuf_dot_descriptor__pb2.MethodOptions.RegisterExtension(scope)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler. DO NOT EDIT!
# See https://github.com/eolymp/contracts/tree/main/cmd/protoc-gen-python-esdk for more details.
"""Generated protocol buffer code."""

from google.protobuf import symbol_database as _symbol_database

_sym_db = _symbol_database.Default()


class RankerClient:
    def __init__(self, transport):
        self.transport = transport

    def CreateScoreboard(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.ranker.Ranker/CreateScoreboard",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.ranker.CreateScoreboardOutput"),
            **kwargs,
        )

    def UpdateScoreboard(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.ranker.Ranker/UpdateScoreboard",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.ranker.UpdateScoreboardOutput"),
            **kwargs,
        )

    def RebuildScoreboard(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.ranker.Ranker/RebuildScoreboard",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.ranker.RebuildScoreboardOutput"),
            **kwargs,
        )

    def DeleteScoreboard(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.ranker.Ranker/DeleteScoreboard",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.ranker.DeleteScoreboardOutput"),
            **kwargs,
        )

    def LookupScoreboard(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.ranker.Ranker/LookupScoreboard",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.ranker.LookupScoreboardOutput"),
            **kwargs,
        )

    def DescribeScoreboard(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.ranker.Ranker/DescribeScoreboard",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.ranker.DescribeScoreboardOutput"),
            **kwargs,
        )

    def ListScoreboards(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.ranker.Ranker/ListScoreboards",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.ranker.ListScoreboardsOutput"),
            **kwargs,
        )

    def ListScoreboardRows(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.ranker.Ranker/ListScoreboardRows",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.ranker.ListScoreboardRowsOutput"),
            **kwargs,
        )

    def AssignContest(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.ranker.Ranker/AssignContest",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.ranker.AssignContestOutput"),
            **kwargs,
        )

    def UnassignContest(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.ranker.Ranker/UnassignContest",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.ranker.UnassignContestOutput"),
            **kwargs,
        )




# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/judge/entitlement.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/judge/entitlement.proto',
  package='eolymp.judge',
  syntax='proto3',
  serialized_options=b'Z1github.com/eolymp/contracts/go/eolymp/judge;judge',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1e\x65olymp/judge/entitlement.proto\x12\x0c\x65olymp.judge*\xff\x02\n\x0b\x45ntitlement\x12\x08\n\x04NONE\x10\x00\x12\x12\n\x0e\x43REATE_CONTEST\x10\x01\x12\x12\n\x0eLOOKUP_CONTEST\x10\x02\x12\x12\n\x0eMANAGE_CONTEST\x10\x03\x12\x10\n\x0cVIEW_RUNTIME\x10\x04\x12\x1a\n\x16VIEW_REGISTRATION_FORM\x10\x05\x12\x14\n\x10VIEW_PARTICIPANT\x10\x06\x12\x16\n\x12MANAGE_PARTICIPANT\x10\x07\x12\x10\n\x0cVIEW_PROBLEM\x10\x08\x12\x12\n\x0eMANAGE_PROBLEM\x10\t\x12\x15\n\x11\x43REATE_SUBMISSION\x10\n\x12\x13\n\x0fVIEW_SUBMISSION\x10\x0b\x12\x15\n\x11MANAGE_SUBMISSION\x10\x0c\x12\x15\n\x11VIEW_ANNOUNCEMENT\x10\r\x12\x17\n\x13MANAGE_ANNOUNCEMENT\x10\x0e\x12\x11\n\rCREATE_TICKET\x10\x0f\x12\x0f\n\x0bVIEW_TICKET\x10\x10\x12\x11\n\rMANAGE_TICKET\x10\x11\x42\x33Z1github.com/eolymp/contracts/go/eolymp/judge;judgeb\x06proto3'
)

_ENTITLEMENT = _descriptor.EnumDescriptor(
  name='Entitlement',
  full_name='eolymp.judge.Entitlement',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CREATE_CONTEST', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOOKUP_CONTEST', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANAGE_CONTEST', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VIEW_RUNTIME', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VIEW_REGISTRATION_FORM', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VIEW_PARTICIPANT', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANAGE_PARTICIPANT', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VIEW_PROBLEM', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANAGE_PROBLEM', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CREATE_SUBMISSION', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VIEW_SUBMISSION', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANAGE_SUBMISSION', index=12, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VIEW_ANNOUNCEMENT', index=13, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANAGE_ANNOUNCEMENT', index=14, number=14,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CREATE_TICKET', index=15, number=15,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VIEW_TICKET', index=16, number=16,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MANAGE_TICKET', index=17, number=17,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=49,
  serialized_end=432,
)
_sym_db.RegisterEnumDescriptor(_ENTITLEMENT)

Entitlement = enum_type_wrapper.EnumTypeWrapper(_ENTITLEMENT)
NONE = 0
CREATE_CONTEST = 1
LOOKUP_CONTEST = 2
MANAGE_CONTEST = 3
VIEW_RUNTIME = 4
VIEW_REGISTRATION_FORM = 5
VIEW_PARTICIPANT = 6
MANAGE_PARTICIPANT = 7
VIEW_PROBLEM = 8
MANAGE_PROBLEM = 9
CREATE_SUBMISSION = 10
VIEW_SUBMISSION = 11
MANAGE_SUBMISSION = 12
VIEW_ANNOUNCEMENT = 13
MANAGE_ANNOUNCEMENT = 14
CREATE_TICKET = 15
VIEW_TICKET = 16
MANAGE_TICKET = 17


DESCRIPTOR.enum_types_by_name['Entitlement'] = _ENTITLEMENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
